AddCommunicationToCaseResponse class

The result of the AddCommunicationToCase operation.

Properties

hashCode → int
The hash code for this object.
no setterinherited
result → bool?
True if AddCommunicationToCase succeeds. Otherwise, returns an error.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited