ResolveCaseResponse class

The status of the case returned by the ResolveCase operation.

Constructors

ResolveCaseResponse({String? finalCaseStatus, String? initialCaseStatus})
ResolveCaseResponse.fromJson(Map<String, dynamic> json)
factory

Properties

finalCaseStatus → String?
The status of the case after the ResolveCase request was processed.
final
hashCode → int
The hash code for this object.
no setterinherited
initialCaseStatus → String?
The status of the case when the ResolveCase request was sent.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited