Service class

Information about an AWS service returned by the DescribeServices operation.

Constructors

Service({List<Category>? categories, String? code, String? name})
Service.fromJson(Map<String, dynamic> json)
factory

Properties

categories → List<Category>?
A list of categories that describe the type of support issue a case describes. Categories consist of a category name and a category code. Category names and codes are passed to AWS Support when you call CreateCase.
final
code → String?
The code for an AWS service returned by the DescribeServices response. The name element contains the corresponding friendly name.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The friendly name for an AWS service. The code element contains the corresponding code.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited