TrustedAdvisorCheckRefreshStatus class

The refresh status of a Trusted Advisor check.

Constructors

TrustedAdvisorCheckRefreshStatus({required String checkId, required int millisUntilNextRefreshable, required String status})
TrustedAdvisorCheckRefreshStatus.fromJson(Map<String, dynamic> json)
factory

Properties

checkId → String
The unique identifier for the Trusted Advisor check.
final
hashCode → int
The hash code for this object.
no setterinherited
millisUntilNextRefreshable → int
The amount of time, in milliseconds, until the Trusted Advisor check is eligible for refresh.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String
The status of the Trusted Advisor check for which a refresh has been requested:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited